@@ -2,7 +2,7 @@ package WWW::ShipStation;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use LWP::UserAgent;
 use JSON;
@@ -107,7 +107,7 @@ sub request {
     $req->authorization_basic($self->{user}, $self->{pass});
     $req->header('Accept', 'application/json'); # JSON is better
     my $res = $self->{ua}->request($req);
-    use Data::Dumper; print STDERR Dumper(\$res);
+    # use Data::Dumper; print STDERR Dumper(\$res);
     if ($res->header('Content-Type') =~ m{application/json}) {
         return $self->{json}->decode($res->decoded_content);
     }
@@ -199,11 +199,11 @@ refer examples for running code
 
 =item * user
 
-required
+required, API key
 
 =item * pass
 
-required
+required, API secret
 
 =item * ua
 
